(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     81162,       1472]
NotebookOptionsPosition[     80045,       1439]
NotebookOutlinePosition[     80419,       1455]
CellTagsIndexPosition[     80376,       1452]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Below is a function ",
 StyleBox["SHM[ ]",
  FontWeight->"Bold"],
 " that integrates a 1D damped simple harmonic oscillator. If you need a 2D \
oscillator or a driving term, modify the function appropriately.\n\nWe want \
to model a function with the following equation of motion:\n\n\tma = F = - k \
x - b v\n\nOr, as a differential equation,\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"\t", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["d", "2"], "x"}], 
      SuperscriptBox["dt", 
       RowBox[{"2", " "}]]], "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["k", "m"]}], "x"}], "-", 
      RowBox[{
       FractionBox["b", "m"], 
       FractionBox["dx", "dt"]}]}]}]}], TraditionalForm]],ExpressionUUID->
  "4181a11d-61f7-4da0-a04c-20be3068b9e6"],
 ".\n\nThis isn\[CloseCurlyQuote]t any harder than the drag equations we\
\[CloseCurlyQuote]ve integrated before. We should be careful in how we \
parameterize it, though. Notice that the book always talks about damping as b \
= \[Beta] ",
 Cell[BoxData[
  FormBox[
   SqrtBox["km"], TraditionalForm]],ExpressionUUID->
  "1372d20a-e94d-48f6-b786-ff6a627a94b4"],
 ", where \[Beta] is a number (2 for critical damping). To see why, write it \
in that way and substitute every ",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{"k", "/", "m"}]], TraditionalForm]],ExpressionUUID->
  "de39063e-7eee-4d2e-ada3-e7c41db66d80"],
 " with \[Omega], which is a property of the undamped oscillator.\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"\t", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["d", "2"], "x"}], 
      SuperscriptBox["dt", 
       RowBox[{"2", " "}]]], "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Omega]", "2"]}], "x"}], "-", 
      RowBox[{"\[Beta]", " ", "\[Omega]", 
       FractionBox["dx", "dt"]}]}]}]}], TraditionalForm]],ExpressionUUID->
  "fc1ec158-e5c0-48fa-8543-81719671fc80"],
 ".\n\nTo make the units of time easy, let\[CloseCurlyQuote]s evaluate \
everything such that the period of the undamped oscillator is one time unit. \
Then, \[Omega] is exactly 2\[Pi]. We won\[CloseCurlyQuote]t impose any \
constraints on the position at t=0 (x0), but making that one seems like a \
fine choice too.\n\nThe arguments of the SHM[ ] function are (in this order):\
\n\[Beta] (damping term such that b = \[Beta] ",
 Cell[BoxData[
  FormBox[
   SqrtBox["km"], TraditionalForm]],ExpressionUUID->
  "5bace0bf-2468-42be-9c46-9021395b62ba"],
 ")\nx0 (the initial position in a unit of your choice)\nv0 (the initial \
velocity in units of the length unit of x0 divided by undamped oscillator \
periods)\ntmax (how many periods to evaluate)\ndt (time step in units of \
periods)\n\nThe function is set up as a Module (see the help file) so it can \
return the list ready for plotting. (With the \[OpenCurlyDoubleQuote]Module\
\[CloseCurlyDoubleQuote] function available, this code could be made much \
more compact, but this is the way we\[CloseCurlyQuote]ve been running so let\
\[CloseCurlyQuote]s keep with what we\[CloseCurlyQuote]re used to.)\n\nNote \
that I update the velocity ",
 StyleBox["before",
  FontSlant->"Italic"],
 " the position. This method (the \[OpenCurlyDoubleQuote]Euler-Cromer method\
\[CloseCurlyDoubleQuote]) is what we\[CloseCurlyQuote]ve been doing the whole \
semester but is crucial here. The Euler method (update ",
 StyleBox["x",
  FontSlant->"Italic"],
 " before ",
 StyleBox["v",
  FontSlant->"Italic"],
 ") famously fails in periodic motion, and this simple swap can rescue it for \
lower-precision needs."
}], "Text",
 CellChangeTimes->{{3.684516933052475*^9, 3.684517010487475*^9}, {
  3.685208129903154*^9, 3.685208129955154*^9}, {3.6852219232604527`*^9, 
  3.685221943026846*^9}, {3.6852220649181376`*^9, 3.685222077687958*^9}, {
  3.689262402661374*^9, 3.6892624203127937`*^9}, {3.6892624515310073`*^9, 
  3.689262591670273*^9}, {3.6892628271960444`*^9, 3.6892629082125363`*^9}, {
  3.689262942062978*^9, 3.689262959617873*^9}, {3.6892839736091228`*^9, 
  3.6892841616968594`*^9}, {3.689284228231736*^9, 3.689284480697033*^9}, {
  3.689284958242521*^9, 3.6892850101641684`*^9}, {3.721209635406468*^9, 
  3.7212096770329676`*^9}},ExpressionUUID->"68dcaf65-c416-4364-bdbd-\
a4ceaaa5f80a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SHM", "[", 
   RowBox[{"\[Beta]_", ",", "x0_", ",", "v0_", ",", "tmax_", ",", "dt_"}], 
   "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"t", ",", "x", ",", "vx", ",", "ax", ",", "result"}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"Initialize", " ", "the", " ", "time"}], ",", " ", "position", 
      ",", " ", "velocity", ",", " ", 
      RowBox[{"and", " ", "result", " ", "array"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"t", "=", "0"}], ";", 
     RowBox[{"x", "=", "x0"}], ";", 
     RowBox[{"vx", "=", "v0"}], ";", 
     RowBox[{"result", "=", 
      RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Test", " ", 
        RowBox[{"condition", ".", " ", "Stop"}], " ", "when", " ", "we", " ", 
        "hit", " ", 
        RowBox[{"tmax", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"t", "\[LessEqual]", "tmax"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", "Body", " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Build", " ", "the", " ", "list", " ", 
         RowBox[{"up", ".", " ", "Put"}], " ", "this", " ", "first", " ", 
         "to", " ", "get", " ", "the", " ", "initial", " ", 
         RowBox[{"condition", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"result", ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "x"}], "}"}]}], "]"}], ";", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "Now", " ", "do", " ", "the", " ", "dynamics", " ", "for", " ", 
          "the", " ", "next", " ", 
          RowBox[{"step", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"ax", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"2", "\[Pi]"}], ")"}], "2"]}], "x"}], "-", 
          RowBox[{"\[Beta]", 
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}], "vx"}]}]}], ";", "   ", 
        RowBox[{"(*", " ", 
         RowBox[{"the", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "\[Pi]"}], ")"}], "'"}], "s", " ", "are", " ", 
          "\[Omega]", " ", "with", " ", "the", " ", "period", " ", "equal", 
          " ", "to", " ", "one"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"vx", "=", 
         RowBox[{"vx", "+", 
          RowBox[{"ax", " ", "dt"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"x", "=", 
         RowBox[{"x", "+", 
          RowBox[{"vx", " ", "dt"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"t", "+=", "dt"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";",
      "\[IndentingNewLine]", "result"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJwlzV1IU2EAxvGzME00iUpYEMuYrMKQYGjoxeR0IaSWqEWhw2CiTKspbsaK
wxjETLELL0bCwA/Yqc2ysebIJemOn0OWCIajZJGmA+1g+yjLqbXO83rx8Lv5
w3NW1VxZf4iiqAvCYFM8o++FlqdLTOfew3Jt6hw84jwagNWPh4IwoHy6DhWF
N7egaHckDKcdX9JtsOvZMfgjiT0Dn1hsRI+4IBtuJO7IoGYtRQ/HEnsmmO/T
mmHlI4ZYvD1ohS1OKQu9MasfnjjOHbiqXoLKre/EGYP9K+zOWl6Bht7QJjyl
kvDwYijjN2yLMsTG8MRf+Lai4d9BX6G3CwZvDT+EO2/k7VClMRJv9+yYoWuv
vB9GDhexcKoq7zl0y+RDkKo96YLmB2o/vM7pPsBa26IiiN8caRHs77ZE4zqe
Pr84K9oVLH0tToaaDgWxuDXso9p4evLSr8/Q6PSvQvFyLAw7OrmfcLpziugu
rJOLBO0zaqI77u3yMjx9d9xghfOX017BfUbmgJ5PjS44UGMkLpl84zDwTeol
/ULuGkyXB0OwJIuLwCstrTHIStpFnOCo9Q/xXs9YCkyy7BOjElcmVK+nnYaz
93UDkDEHXsKyuVw37Lt6jVjapI+w73j6442VbfgfJAZu8A==
  "],ExpressionUUID->"be7fa260-d960-4ead-8e07-3fcde5d8b081"],

Cell["\<\
With that function ready to go, here\[CloseCurlyQuote]s an undamped \
oscillator starting at rest displaced to x0 = 1 and evaluated for 10 periods \
(200 time steps per period).\
\>", "Text",
 CellChangeTimes->{{3.6892844981178093`*^9, 
  3.6892845593842688`*^9}},ExpressionUUID->"2c3fef7a-da33-4597-a071-\
1d2fa5f3b86c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"SHM", "[", 
    RowBox[{"0", ",", "1", ",", "0", ",", "10", ",", "0.005"}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], "\[IndentingNewLine]", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<t / T\>\"", ",", "\"\<x / x0\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.689282855676458*^9, 3.6892828696945057`*^9}, {
  3.68928383181124*^9, 3.6892838553517942`*^9}, {3.6892841921031466`*^9, 
  3.689284192400076*^9}, {3.689284534719215*^9, 
  3.6892846411078386`*^9}},ExpressionUUID->"097f466d-8eaf-4132-96b6-\
6510b34590f6"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxU3GVYVG3XxnG6Y+gUsRsLO9aSUhSxEztQsbG7UTEAwW5RwQ4QVNCLEAQE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      "]]}, {}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t / T\"", TraditionalForm], 
    FormBox["\"x / x0\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 9.995000000000163}, {-1.0000355534123002`, 
    1.0000372576954686`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.689282870851127*^9, 3.6892829177998314`*^9, {3.6892838266335344`*^9, 
   3.689283856117455*^9}, 3.689284192978181*^9, {3.6892845309590635`*^9, 
   3.689284545419262*^9}, 3.689284599610608*^9, {3.6892846307958636`*^9, 
   3.689284641764101*^9}, 
   3.721209797271332*^9},ExpressionUUID->"399a0766-6d22-45f0-8fcf-\
b9ebc2a0d2c2"]
}, Open  ]],

Cell["\<\
Here' s an example of an underdamped (\[Beta] = 0.1) oscillator that starts \
displaced and moving. Note that because its initial velocity (20 \
length-units/period) is positive, it begins moving farther from equilibrium \
than its 1.0 length-unit displacement.\
\>", "Text",
 CellChangeTimes->{{3.68928465523851*^9, 3.6892847112507496`*^9}, {
  3.6892847496390324`*^9, 
  3.689284803910245*^9}},ExpressionUUID->"0e778c7c-22e7-4cd0-b762-\
4d9e4c3ba2fc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"SHM", "[", 
    RowBox[{"0.1", ",", "1.0", ",", "20", ",", "10", ",", "0.005"}], "]"}], 
   ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], "\[IndentingNewLine]", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<t / T\>\"", ",", "\"\<x / x0\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.689284693033142*^9, 
  3.689284738136973*^9}},ExpressionUUID->"d5e75aa2-ab01-44a2-a1b5-\
e54d30ad129a"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxU23dcze//+PH2Hud02vVGhazMyH4+FVkJWSErMpJCqczIJiHJziYroYjU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      "]]}, {}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t / T\"", TraditionalForm], 
    FormBox["\"x / x0\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 9.995000000000163}, {-2.702235183078695, 
    3.1628280985359036`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.68928469896867*^9, 3.6892847386838546`*^9}, 
   3.7212098100223675`*^9},ExpressionUUID->"0fbb5b30-da88-4dcc-bd4f-\
0cf6e6352a55"]
}, Open  ]]
},
WindowSize->{872, 668},
WindowMargins->{{290, Automatic}, {Automatic, 72}},
Magnification:>1.2 Inherited,
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 4322, 98, 890, "Text", "ExpressionUUID" -> \
"68dcaf65-c416-4364-bdbd-a4ceaaa5f80a"],
Cell[4883, 120, 3761, 85, 464, "Input", "ExpressionUUID" -> \
"be7fa260-d960-4ead-8e07-3fcde5d8b081"],
Cell[8647, 207, 331, 7, 58, "Text", "ExpressionUUID" -> \
"2c3fef7a-da33-4597-a071-1d2fa5f3b86c"],
Cell[CellGroupData[{
Cell[9003, 218, 642, 14, 62, "Input", "ExpressionUUID" -> \
"097f466d-8eaf-4132-96b6-6510b34590f6"],
Cell[9648, 234, 34746, 587, 276, "Output", "ExpressionUUID" -> \
"399a0766-6d22-45f0-8fcf-b9ebc2a0d2c2"]
}, Open  ]],
Cell[44409, 824, 463, 9, 81, "Text", "ExpressionUUID" -> \
"0e778c7c-22e7-4cd0-b762-4d9e4c3ba2fc"],
Cell[CellGroupData[{
Cell[44897, 837, 500, 13, 62, "Input", "ExpressionUUID" -> \
"d5e75aa2-ab01-44a2-a1b5-e54d30ad129a"],
Cell[45400, 852, 34629, 584, 288, "Output", "ExpressionUUID" -> \
"0fbb5b30-da88-4dcc-bd4f-0cf6e6352a55"]
}, Open  ]]
}
]
*)

